onTick property
Simulation callback, runs once per fixed tick before replication flushes.
Implementation
final void Function(int tick)? onTick;
Simulation callback, runs once per fixed tick before replication flushes.
final void Function(int tick)? onTick;