StructCodec<T> class final

Convenience for building one-off payload codecs for RPC argument records.

Implemented types

Constructors

StructCodec({required String id, required void encode(ByteWriter, T), required T decode(ByteReader)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(ByteReader r) → T
override
encode(ByteWriter w, T value) → void
override
equals(T a, T b) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited