RpcEndpoint<T> class
final
A remote-procedure endpoint declared on a Replica.
Properties
-
codec
→ Codec<
T> -
final
- delivery → Delivery
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- name → String
-
final
- replica → Replica
-
final
- requireOwner → bool
-
For RpcTarget.server endpoints, whether only the owner may call.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → RpcTarget
-
final
Methods
-
call(
T args) → void - Invokes the endpoint. On a client this sends to the server (for RpcTarget.server endpoints); on the server it sends to the targeted peers, and RpcTarget.all also runs the handler locally.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited